Skip to contents

A subset of data from the Map of Miletus for testing and demonstrating working with the R-Package chrongler.

Usage

BuildingsMilet

Format

BuildingsMilet

A data frame with 110 rows and 3 columns:

identifier

The name of a building in Miletus.

period.start

The earliest period the building can be dated to.

period.end

The latest period the building can be dated to.