Skip to contents

This is a slightly adapted set of periods as used by the Miletus Excavation, for details see the "Miletus Documentation Manual": Miletus Documentation Manual: Surveying, Forms, Find Processing and Database Usage, v.2.0, https://doi.org/10.25592/uhhfdm.10029

Usage

PeriodsMilet

Format

PeriodsMilet

A data frame with 19 rows and 5 columns:

group

The 'group' of periods the periods belongs to.

values

The label of the period.

dating.min

The "starting" year of the period.

dating.max

The last year of the period.

color

The color scheme as used by the Map of Miletus (see "BuildingsMilet" dataset).