BuildingsMilet.Rd
A subset of data from the Map of Miletus for testing and demonstrating working with the R-Package chrongler.
BuildingsMilet
A data frame with 110 rows and 3 columns:
The name of a building in Miletus.
The earliest period the building can be dated to.
The latest period the building can be dated to.
https://geoserver.dainst.org/catalogue/uuid/53438148-30d1-11ec-9582-0242ac140004